##  Editing in the Transformations Explorer
**Note**
Confirm you have the necessary permissions to edit or execute transformations. Learn more about the available permissions for transformations in [Role-Based Permissions](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions?locale=en-US&state=PRODUCTION&version=CLOUD#loio275def827a4410149362f3672c614956__role-based_permissions).
The transformations explorer lets you edit, execute, and delete transformations in bulk. This simplifies managing large numbers of changes, saving time and effort. You can make the changes in the following way:
  1. Switch to edit mode by selecting the pencil icon in the toolbar.
  2. Make your changes, you can:
    1. Copy and paste content between cells.
    2. Autofill columns by dragging the fill handle at bottom-right corner of a cell.
    3. Update completion dates using the date picker or milestone dropdown.
    4. Delete a transformation item by right-clicking and selecting Delete Transformations.
  3. Review your changes. Modified cells will appear in light yellow.
  4. Choose Save to apply your changes.


![Editing Behavior in All Transformations View](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiob1e26fdf908c42be988aa1f58eaccb0f_LowRes.gif)
Editing Behavior in All Transformations View
**Note**
  * You can update template-specific fields, such as the fact sheets being introduced or rolled out, when you have filtered by a specific transformation type. Use the dropdowns in relevant fields to make the updates.
  * Custom impacts cannot be edited directly in the transformations explorer. Learn more about modifying impacts in [Managing Impacts in the Transformations Explorer](https://help.sap.com/docs/leanix/ea/transformations-explorer?locale=en-US&state=PRODUCTION&version=CLOUD#loio98623f7d5c9b44e5a42c787307e0a027__Managing-Impacts-in-the-Transformations-Explorer).


![Editing Template-Specific Fields](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio197104f8e1f04b8a94d35bb8c1d2afb0_LowRes.png)
Editing Template-Specific Fields
